@@ -86,9 +86,13 @@ class ScanningFile(LicelFile):
         raw_info = {}
 
         third_line = f.readline().decode()
+        self.header_lines.append(third_line.strip())
+
         raw_info.update(self.match_lines(third_line, self.licel_file_header_format[2]))
 
         fourth_line = f.readline().decode()
+        self.header_lines.append(fourth_line.strip())
+
         raw_info.update(self.match_lines(fourth_line, self.licel_file_header_format[3]))
         return raw_info
 
